@@ -23,6 +23,7 @@
 #include <backends/abstractbackend.h>
 
 #include <QtCore/QStringList>
+#include <QRect>
 
 namespace KScreen {
 
@@ -421,6 +422,11 @@ void Output::setSizeMm(const QSize &size)
     d->sizeMm = size;
 }
 
+QRect Output::geometry() const
+{
+    return QRect(pos(), currentMode()->size());
+}
+
 } //KScreen namespace
 
 QDebug operator<<(QDebug dbg, const KScreen::Output *output)
